import { HttpClient, NonNullablePaths, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { SubscriptionContract, SubscriptionContractsQueryBuilder, SubscriptionContractCreatedEnvelope, SubscriptionContractDeletedEnvelope, SubscriptionContractUpdatedEnvelope } from './index.typings.js';
export { ActionEvent, AdditionalFee, Address, AddressLocation, AddressWithContact, AdjustmentType, AppliedDiscount, AppliedDiscountDiscountSourceOneOf, BaseEventMetadata, BillingAdjustment, BillingAdjustmentPriceSummary, BuyerInfo, BuyerInfoIdOneOf, CatalogReference, ChannelInfo, ChannelType, Color, Coupon, CreateSubscriptionContractRequest, CreateSubscriptionContractResponse, CurrencyConversionDetails, CursorPaging, CursorPagingMetadata, CursorQuery, CursorQueryPagingMethodOneOf, Cursors, CustomField, DeliveryLogistics, DeliveryLogisticsAddressOneOf, DeliveryTimeSlot, DescriptionLine, DescriptionLineDescriptionLineValueOneOf, DescriptionLineName, DescriptionLineType, DescriptionLineValueOneOf, DigitalFile, DiscountReason, DiscountRule, DiscountRuleName, DiscountType, DomainEvent, DomainEventBodyOneOf, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, ExtendedFields, FocalPoint, FreeTrialPeriod, FullAddressContactDetails, GetSubscriptionContractRequest, GetSubscriptionContractResponse, IdentificationData, IdentificationDataIdOneOf, ItemModifier, ItemTaxFullDetails, ItemType, ItemTypeItemType, ItemTypeItemTypeDataOneOf, JurisdictionType, LineItemDiscount, LineItemTaxBreakdown, LineItemTaxInfo, Location, LocationAndQuantity, MerchantDiscount, MerchantDiscountMerchantDiscountReasonOneOf, MessageEnvelope, ModifierGroup, OrderLineItem, OrderTaxBreakdown, OrderTaxInfo, PaymentOptionType, PhysicalProperties, PickupAddress, PickupDetails, PickupMethod, PlainTextValue, Price, PriceDescription, PriceSummary, ProductName, QuerySubscriptionContractsRequest, QuerySubscriptionContractsResponse, RestoreInfo, ShippingInformation, ShippingPrice, ShippingRegion, SortOrder, Sorting, StreetAddress, SubscriptionContractsQueryResult, SubscriptionDescription, SubscriptionFrequency, SubscriptionInfo, SubscriptionSettings, SubscriptionTitle, TaxableAddress, TaxableAddressTaxableAddressDataOneOf, TaxableAddressType, TranslatableString, UpdateSubscriptionContractRequest, UpdateSubscriptionContractResponse, V1FreeTrialPeriod, V1SubscriptionDescription, V1SubscriptionSettings, V1SubscriptionTitle, V2SubscriptionFrequency, VatId, VatType, WebhookIdentityType, WeightUnit } from './index.typings.js';

type SubscriptionContractNonNullablePaths = `subscriptionSettings.frequency` | `subscriptionSettings.autoRenewal` | `subscriptionSettings.enableCustomerCancellation` | `subscriptionSettings.freeTrialPeriod.frequency` | `subscriptionSettings.freeTrialPeriod.interval` | `lineItems` | `lineItems.${number}._id` | `lineItems.${number}.productName.original` | `lineItems.${number}.catalogReference.catalogItemId` | `lineItems.${number}.catalogReference.appId` | `lineItems.${number}.quantity` | `lineItems.${number}.totalDiscount.amount` | `lineItems.${number}.totalDiscount.formattedAmount` | `lineItems.${number}.physicalProperties.shippable` | `lineItems.${number}.itemType.preset` | `lineItems.${number}.itemType.custom` | `lineItems.${number}.paymentOption` | `lineItems.${number}.taxDetails.taxRate` | `lineItems.${number}.taxInfo.taxIncludedInPrice` | `lineItems.${number}.digitalFile.fileId` | `lineItems.${number}.subscriptionInfo.cycleNumber` | `lineItems.${number}.subscriptionInfo.subscriptionOptionTitle` | `lineItems.${number}.subscriptionInfo.subscriptionSettings.frequency` | `lineItems.${number}.subscriptionInfo.subscriptionSettings.autoRenewal` | `lineItems.${number}.subscriptionInfo.subscriptionSettings.enableCustomerCancellation` | `lineItems.${number}.subscriptionInfo.subscriptionSettings.freeTrialPeriod.frequency` | `lineItems.${number}.subscriptionInfo.subscriptionSettings.freeTrialPeriod.interval` | `lineItems.${number}.priceDescription.original` | `lineItems.${number}.taxableAddress.addressType` | `buyerInfo.visitorId` | `buyerInfo.memberId` | `weightUnit` | `taxIncludedInPrices` | `priceSummary.subtotal.amount` | `priceSummary.subtotal.formattedAmount` | `billingInfo.address.streetAddress.number` | `billingInfo.address.streetAddress.name` | `billingInfo.contactDetails.vatId._id` | `billingInfo.contactDetails.vatId.type` | `shippingInfo.title` | `shippingInfo.logistics.shippingDestination.address.streetAddress.number` | `shippingInfo.logistics.shippingDestination.address.streetAddress.name` | `shippingInfo.logistics.shippingDestination.contactDetails.vatId._id` | `shippingInfo.logistics.shippingDestination.contactDetails.vatId.type` | `shippingInfo.logistics.pickupDetails.pickupMethod` | `shippingInfo.cost.price.amount` | `shippingInfo.cost.price.formattedAmount` | `shippingInfo.cost.taxDetails.taxRate` | `appliedDiscounts` | `appliedDiscounts.${number}.coupon._id` | `appliedDiscounts.${number}.coupon.code` | `appliedDiscounts.${number}.coupon.name` | `appliedDiscounts.${number}.coupon.amount.amount` | `appliedDiscounts.${number}.coupon.amount.formattedAmount` | `appliedDiscounts.${number}.merchantDiscount.discountReason` | `appliedDiscounts.${number}.discountRule._id` | `appliedDiscounts.${number}.discountRule.name.original` | `appliedDiscounts.${number}.discountType` | `channelInfo.type` | `customFields` | `customFields.${number}.title` | `recipientInfo.address.streetAddress.number` | `recipientInfo.address.streetAddress.name` | `recipientInfo.contactDetails.vatId._id` | `recipientInfo.contactDetails.vatId.type` | `additionalFees` | `additionalFees.${number}.name` | `additionalFees.${number}.price.amount` | `additionalFees.${number}.price.formattedAmount` | `additionalFees.${number}.taxDetails.taxRate` | `additionalFees.${number}._id`;
declare function getSubscriptionContract$1(httpClient: HttpClient): GetSubscriptionContractSignature;
interface GetSubscriptionContractSignature {
    /**
     * Retrieves a SubscriptionContract.
     * @param - ID of the SubscriptionContract to retrieve.
     * @returns The requested SubscriptionContract.
     */
    (subscriptionContractId: string): Promise<NonNullablePaths<SubscriptionContract, SubscriptionContractNonNullablePaths>>;
}
declare function querySubscriptionContracts$1(httpClient: HttpClient): QuerySubscriptionContractsSignature;
interface QuerySubscriptionContractsSignature {
    /**
     * Retrieves a list of SubscriptionContracts, given the provided [paging, filtering, and sorting][1].
     *
     * Up to 300 SubscriptionContracts can be returned per request.
     *
     * To learn how to query SubscriptionContracts, see [API Query Language][2].
     *
     * [1]: https://dev.wix.com/api/rest/getting-started/sorting-and-paging
     * [2]: https://dev.wix.com/api/rest/getting-started/api-query-language
     */
    (): SubscriptionContractsQueryBuilder;
}
declare const onSubscriptionContractCreated$1: EventDefinition<SubscriptionContractCreatedEnvelope, "wix.ecom.subscription_contracts.v1.subscription_contract_created">;
declare const onSubscriptionContractDeleted$1: EventDefinition<SubscriptionContractDeletedEnvelope, "wix.ecom.subscription_contracts.v1.subscription_contract_deleted">;
declare const onSubscriptionContractUpdated$1: EventDefinition<SubscriptionContractUpdatedEnvelope, "wix.ecom.subscription_contracts.v1.subscription_contract_updated">;

declare const getSubscriptionContract: MaybeContext<BuildRESTFunction<typeof getSubscriptionContract$1> & typeof getSubscriptionContract$1>;
declare const querySubscriptionContracts: MaybeContext<BuildRESTFunction<typeof querySubscriptionContracts$1> & typeof querySubscriptionContracts$1>;
/** */
declare const onSubscriptionContractCreated: BuildEventDefinition<typeof onSubscriptionContractCreated$1>;
/** */
declare const onSubscriptionContractDeleted: BuildEventDefinition<typeof onSubscriptionContractDeleted$1>;
/** */
declare const onSubscriptionContractUpdated: BuildEventDefinition<typeof onSubscriptionContractUpdated$1>;

export { SubscriptionContract, SubscriptionContractCreatedEnvelope, SubscriptionContractDeletedEnvelope, SubscriptionContractUpdatedEnvelope, SubscriptionContractsQueryBuilder, getSubscriptionContract, onSubscriptionContractCreated, onSubscriptionContractDeleted, onSubscriptionContractUpdated, querySubscriptionContracts };
